@@ -3,14 +3,14 @@ import numpy as np
 
 
 def test_leakage():
-    from ctapipe.image.leakage import leakage
+    from ctapipe.image.leakage import leakage_parameters
 
     geom = CameraGeometry.from_name("LSTCam")
 
     img = np.ones(geom.n_pixels)
     mask = np.ones(len(geom), dtype=bool)
 
-    l = leakage(geom, img, mask)
+    l = leakage_parameters(geom, img, mask)
 
     ratio1 = np.sum(geom.get_border_pixel_mask(1)) / geom.n_pixels
     ratio2 = np.sum(geom.get_border_pixel_mask(2)) / geom.n_pixels
