@@ -1,4 +1,5 @@
 import astropy.units as u
+from astropy.utils.decorators import lazyproperty
 import logging
 import numpy as np
 import tables
@@ -19,6 +20,7 @@ from ctapipe.containers import (
     PeakTimeStatisticsContainer,
     TimingParametersContainer,
     TriggerContainer,
+    ImageParametersContainer,
 )
 from ctapipe.utils import IndexFinder
 
@@ -59,7 +61,7 @@ class DL1EventSource(EventSource):
         depending on the information present in the file.
     is_simulation: Boolean
         Whether the events are simulated or observed.
-    mc_headers: Dict
+    simulation_configs: Dict
         Mapping of obs_id to ctapipe.containers.SimulationConfigContainer
         if the file contains simulated events.
     has_simulated_dl1: Boolean
@@ -68,7 +70,7 @@ class DL1EventSource(EventSource):
 
     """
 
-    def __init__(self, input_url, config=None, parent=None, **kwargs):
+    def __init__(self, input_url=None, config=None, parent=None, **kwargs):
         """
         EventSource for dl1 files in the standard DL1 data format
 
@@ -86,13 +88,20 @@ class DL1EventSource(EventSource):
         """
         super().__init__(input_url=input_url, config=config, parent=parent, **kwargs)
 
-        self.file_ = tables.open_file(input_url)
-        self.input_url = input_url
+        self.file_ = tables.open_file(self.input_url)
         self._subarray_info = SubarrayDescription.from_hdf(self.input_url)
-        self._mc_headers = self._parse_mc_headers()
+        self._simulation_configs = self._parse_simulation_configs()
         self.datamodel_version = self.file_.root._v_attrs[
             "CTA PRODUCT DATA MODEL VERSION"
         ]
+        params = "parameters" in self.file_.root.dl1.event.telescope
+        images = "images" in self.file_.root.dl1.event.telescope
+        if params and images:
+            self._datalevels = (DataLevel.DL1_IMAGES, DataLevel.DL1_PARAMETERS)
+        elif params:
+            self._datalevels = (DataLevel.DL1_PARAMETERS,)
+        elif images:
+            self._datalevels = (DataLevel.DL1_IMAGES,)
 
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
@@ -144,22 +153,21 @@ class DL1EventSource(EventSource):
 
     @property
     def datalevels(self):
-        params = "parameters" in self.file_.root.dl1.event.telescope
-        images = "images" in self.file_.root.dl1.event.telescope
-        if params and images:
-            return (DataLevel.DL1_IMAGES, DataLevel.DL1_PARAMETERS)
-        elif params:
-            return (DataLevel.DL1_PARAMETERS,)
-        elif images:
-            return (DataLevel.DL1_IMAGES,)
+        return self._datalevels
 
-    @property
+    @lazyproperty
     def obs_ids(self):
         return list(np.unique(self.file_.root.dl1.event.subarray.trigger.col("obs_id")))
 
     @property
-    def mc_headers(self):
-        return self._mc_headers
+    def simulation_config(self):
+        """
+        Returns the simulation config.
+        In case of a merged file, this will be a list of simulation configs.
+        """
+        if len(self._simulation_configs) == 1:
+            return next(iter(self._simulation_configs.values()))
+        return self._simulation_configs
 
     def _generator(self):
         yield from self._generate_events()
@@ -167,7 +175,7 @@ class DL1EventSource(EventSource):
     def __len__(self):
         return len(self.file_.root.dl1.event.subarray.trigger)
 
-    def _parse_mc_headers(self):
+    def _parse_simulation_configs(self):
         """
         Construct a dict of SimulationConfigContainers from the
         self.file_.root.configuration.simulation.run.
@@ -179,15 +187,15 @@ class DL1EventSource(EventSource):
         # the correct mcheader assigned by matching the obs_id
         # Alternatively this becomes a flat list
         # and the obs_id matching part needs to be done in _generate_events()
-        mc_headers = {}
+        simulation_configs = {}
         if "simulation" in self.file_.root.configuration:
             reader = HDF5TableReader(self.file_).read(
-                "/configuration/simulation/run", SimulationConfigContainer()
+                "/configuration/simulation/run",
+                containers=[SimulationConfigContainer(), EventIndexContainer()],
             )
-            row_iterator = self.file_.root.configuration.simulation.run.iterrows()
-            for row in row_iterator:
-                mc_headers[row["obs_id"]] = next(reader)
-        return mc_headers
+            for (config, index) in reader:
+                simulation_configs[index.obs_id] = config
+        return simulation_configs
 
     def _generate_events(self):
         """
@@ -270,17 +278,18 @@ class DL1EventSource(EventSource):
             for tel in self.file_.root.dl1.monitoring.telescope.pointing
         }
 
-        for counter, array_event in enumerate(events):
+        for counter, (trigger, index) in enumerate(events):
             data.dl1.tel.clear()
             data.simulation.tel.clear()
             data.pointing.tel.clear()
             data.trigger.tel.clear()
 
             data.count = counter
-            data.trigger, data.index = next(events)
-            data.trigger.tels_with_trigger = (
-                np.where(data.trigger.tels_with_trigger)[0] + 1
-            )  # +1 to match array index to telescope id
+            data.trigger = trigger
+            data.index = index
+            data.trigger.tels_with_trigger = self.subarray.tel_mask_to_tel_ids(
+                data.trigger.tels_with_trigger
+            )
 
             # Maybe there is a simpler way  to do this
             # Beware: tels_with_trigger contains all triggered telescopes whereas
@@ -344,13 +353,15 @@ class DL1EventSource(EventSource):
                     # Best would probbaly be if we could directly read
                     # into the ImageParametersContainer
                     params = next(param_readers[f"tel_{tel:03d}"])
-                    dl1.parameters.hillas = params[0]
-                    dl1.parameters.timing = params[1]
-                    dl1.parameters.leakage = params[2]
-                    dl1.parameters.concentration = params[3]
-                    dl1.parameters.morphology = params[4]
-                    dl1.parameters.intensity_statistics = params[5]
-                    dl1.parameters.peak_time_statistics = params[6]
+                    dl1.parameters = ImageParametersContainer(
+                        hillas=params[0],
+                        timing=params[1],
+                        leakage=params[2],
+                        concentration=params[3],
+                        morphology=params[4],
+                        intensity_statistics=params[5],
+                        peak_time_statistics=params[6],
+                    )
 
                     if self.has_simulated_dl1:
                         if f"tel_{tel:03d}" not in param_readers.keys():
@@ -363,13 +374,13 @@ class DL1EventSource(EventSource):
                         simulated_params = next(
                             simulated_param_readers[f"tel_{tel:03d}"]
                         )
-                        simulated.true_parameters.hillas = simulated_params[0]
-                        simulated.true_parameters.leakage = simulated_params[1]
-                        simulated.true_parameters.concentration = simulated_params[2]
-                        simulated.true_parameters.morphology = simulated_params[3]
-                        simulated.true_parameters.intensity_statistics = simulated_params[
-                            4
-                        ]
+                        simulated.true_parameters = ImageParametersContainer(
+                            hillas=simulated_params[0],
+                            leakage=simulated_params[1],
+                            concentration=simulated_params[2],
+                            morphology=simulated_params[3],
+                            intensity_statistics=simulated_params[4],
+                        )
 
             yield data
 
