@@ -18,6 +18,8 @@ from ..containers import (
     SimulationConfigContainer,
     SimulatedCameraContainer,
     SimulatedShowerContainer,
+    TelescopePointingContainer,
+    TelescopeTriggerContainer,
 )
 from ..coordinates import CameraFrame
 from ..core.traits import Bool, CaselessStrEnum, create_class_enum_trait
@@ -50,12 +52,13 @@ SIMTEL_TO_CTA_EVENT_TYPE = {
 }
 
 
+NANOSECONDS_PER_DAY = (1 * u.day).to_value(u.ns)
+
+
 def parse_simtel_time(simtel_time):
+    """Convert a unix time second / nanosecond tuple into astropy.time.Time"""
     return Time(
-        u.Quantity(simtel_time[0], u.s),
-        u.Quantity(simtel_time[1], u.ns),
-        format="unix",
-        scale="utc",
+        simtel_time[0], simtel_time[1] * 1e-9, format="unix", scale="utc"  # ns to s
     )
 
 
@@ -402,8 +405,8 @@ class SimTelEventSource(EventSource):
                     true_image=true_image
                 )
 
-                self._fill_event_pointing(
-                    data.pointing.tel[tel_id], tracking_positions[tel_id]
+                data.pointing.tel[tel_id] = self._fill_event_pointing(
+                    tracking_positions[tel_id]
                 )
 
                 r0 = data.r0.tel[tel_id]
@@ -429,7 +432,7 @@ class SimTelEventSource(EventSource):
             yield data
 
     @staticmethod
-    def _fill_event_pointing(pointing, tracking_position):
+    def _fill_event_pointing(tracking_position):
         azimuth_raw = tracking_position["azimuth_raw"]
         altitude_raw = tracking_position["altitude_raw"]
         azimuth_cor = tracking_position.get("azimuth_cor", np.nan)
@@ -437,15 +440,17 @@ class SimTelEventSource(EventSource):
 
         # take pointing corrected position if available
         if np.isnan(azimuth_cor):
-            pointing.azimuth = u.Quantity(azimuth_raw, u.rad)
+            azimuth = u.Quantity(azimuth_raw, u.rad, copy=False)
         else:
-            pointing.azimuth = u.Quantity(azimuth_cor, u.rad)
+            azimuth = u.Quantity(azimuth_cor, u.rad, copy=False)
 
         # take pointing corrected position if available
         if np.isnan(altitude_cor):
-            pointing.altitude = u.Quantity(altitude_raw, u.rad)
+            altitude = u.Quantity(altitude_raw, u.rad, copy=False)
         else:
-            pointing.altitude = u.Quantity(altitude_cor, u.rad)
+            altitude = u.Quantity(altitude_cor, u.rad, copy=False)
+
+        return TelescopePointingContainer(azimuth=azimuth, altitude=altitude)
 
     @staticmethod
     def _fill_trigger_info(data, array_event):
@@ -464,23 +469,37 @@ class SimTelEventSource(EventSource):
             data.trigger.event_type = EventType.UNKNOWN
 
         data.trigger.tels_with_trigger = trigger["triggered_telescopes"]
-        data.trigger.time = parse_simtel_time(trigger["gps_time"])
+        central_time = parse_simtel_time(trigger["gps_time"])
+        data.trigger.time = central_time
 
         for tel_id, time in zip(
             trigger["triggered_telescopes"], trigger["trigger_times"]
         ):
-            # time is relative to central trigger in nano seconds
-            trigger = data.trigger.tel[tel_id]
-            trigger.time = data.trigger.time + u.Quantity(time, u.ns)
+            # telesocpe time is relative to central trigger in ns
+            time = Time(
+                central_time.jd1,
+                central_time.jd2 + time / NANOSECONDS_PER_DAY,
+                scale=central_time.scale,
+                format="jd",
+            )
 
             # triggered pixel info
+            n_trigger_pixels = -1
+            trigger_pixels = None
+
             tel_event = array_event["telescope_events"].get(tel_id)
             if tel_event:
                 # code 0 = trigger pixels
                 pixel_list = tel_event["pixel_lists"].get(0)
                 if pixel_list:
-                    trigger.n_trigger_pixels = pixel_list["pixels"]
-                    trigger.trigger_pixels = pixel_list["pixel_list"]
+                    n_trigger_pixels = pixel_list["pixels"]
+                    trigger_pixels = pixel_list["pixel_list"]
+
+            trigger = data.trigger.tel[tel_id] = TelescopeTriggerContainer(
+                time=time,
+                n_trigger_pixels=n_trigger_pixels,
+                trigger_pixels=trigger_pixels,
+            )
 
     def _fill_array_pointing(self, data):
         if self.file_.header["tracking_mode"] == 0:
