@@ -11,7 +11,7 @@ from ctapipe.core.container import Container, Field
 from ctapipe import containers
 from ctapipe.containers import (
     R0CameraContainer,
-    MCEventContainer,
+    SimulatedShowerContainer,
     HillasParametersContainer,
     LeakageContainer,
 )
@@ -20,7 +20,7 @@ from ctapipe.io.hdf5tableio import HDF5TableWriter, HDF5TableReader
 
 @pytest.fixture(scope="session")
 def temp_h5_file(tmpdir_factory):
-    """ a fixture that fetches a temporary output dir/file for a test
+    """a fixture that fetches a temporary output dir/file for a test
     file that we want to read or write (so it doesn't clutter up the test
     directory when the automated tests are run)"""
     return str(tmpdir_factory.mktemp("data").join("test.h5"))
@@ -28,8 +28,8 @@ def temp_h5_file(tmpdir_factory):
 
 def test_write_container(temp_h5_file):
     r0tel = R0CameraContainer()
-    mc = MCEventContainer()
-    mc.reset()
+    simshower = SimulatedShowerContainer()
+    simshower.reset()
     r0tel.waveform = np.random.uniform(size=(50, 10))
     r0tel.meta["test_attribute"] = 3.14159
     r0tel.meta["date"] = "2020-10-10"
@@ -41,17 +41,16 @@ def test_write_container(temp_h5_file):
 
         for ii in range(100):
             r0tel.waveform[:] = np.random.uniform(size=(50, 10))
-            mc.energy = 10 ** np.random.uniform(1, 2) * u.TeV
-            mc.core_x = np.random.uniform(-1, 1) * u.m
-            mc.core_y = np.random.uniform(-1, 1) * u.m
+            simshower.energy = 10 ** np.random.uniform(1, 2) * u.TeV
+            simshower.core_x = np.random.uniform(-1, 1) * u.m
+            simshower.core_y = np.random.uniform(-1, 1) * u.m
 
             writer.write("tel_001", r0tel)
             writer.write("tel_002", r0tel)  # write a second table too
-            writer.write("MC", mc)
+            writer.write("sim_shower", simshower)
 
 
-def test_prefix(tmp_path):
-    tmp_file = tmp_path / "test_prefix.hdf5"
+def test_read_multiple_containers():
     hillas_parameter_container = HillasParametersContainer(
         x=1 * u.m, y=1 * u.m, length=1 * u.m, width=1 * u.m
     )
@@ -62,13 +61,165 @@ def test_prefix(tmp_path):
         intensity_width_1=0.1,
         intensity_width_2=0.1,
     )
+    with tempfile.NamedTemporaryFile() as f:
+        with HDF5TableWriter(f.name, group_name="dl1", add_prefix=True) as writer:
+            writer.write("params", [hillas_parameter_container, leakage_container])
 
-    with HDF5TableWriter(tmp_file.name, group_name="blabla", add_prefix=True) as writer:
-        writer.write("events", [hillas_parameter_container, leakage_container])
+        df = pd.read_hdf(f.name, key="/dl1/params")
+        assert "hillas_x" in df.columns
+        assert "leakage_pixels_width_1" in df.columns
 
-    df = pd.read_hdf(tmp_file.name, key="/blabla/events")
-    assert "hillas_x" in df.columns
-    assert "leakage_pixels_width_1" in df.columns
+        # test reading both containers separately
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read(
+                "/dl1/params", HillasParametersContainer(), prefixes=True
+            )
+            hillas = next(generator)
+        for value, read_value in zip(
+            hillas_parameter_container.as_dict().values(), hillas.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read("/dl1/params", LeakageContainer(), prefixes=True)
+            leakage = next(generator)
+        for value, read_value in zip(
+            leakage_container.as_dict().values(), leakage.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        # test reading both containers simultaneously
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read(
+                "/dl1/params",
+                [HillasParametersContainer(), LeakageContainer()],
+                prefixes=True,
+            )
+            hillas_, leakage_ = next(generator)
+
+        for value, read_value in zip(
+            leakage_container.as_dict().values(), leakage_.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        for value, read_value in zip(
+            hillas_parameter_container.as_dict().values(), hillas_.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+
+def test_read_without_prefixes():
+    hillas_parameter_container = HillasParametersContainer(
+        x=1 * u.m, y=1 * u.m, length=1 * u.m, width=1 * u.m
+    )
+
+    leakage_container = LeakageContainer(
+        pixels_width_1=0.1,
+        pixels_width_2=0.1,
+        intensity_width_1=0.1,
+        intensity_width_2=0.1,
+    )
+    with tempfile.NamedTemporaryFile() as f:
+        with HDF5TableWriter(f.name, group_name="dl1", add_prefix=False) as writer:
+            writer.write("params", [hillas_parameter_container, leakage_container])
+
+        df = pd.read_hdf(f.name, key="/dl1/params")
+        assert "x" in df.columns
+        assert "pixels_width_1" in df.columns
+
+        # call with prefixes=False
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read(
+                "/dl1/params",
+                [HillasParametersContainer(), LeakageContainer()],
+                prefixes=False,
+            )
+            hillas_, leakage_ = next(generator)
+
+        for value, read_value in zip(
+            leakage_container.as_dict().values(), leakage_.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        for value, read_value in zip(
+            hillas_parameter_container.as_dict().values(), hillas_.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        # call with manually removed prefixes
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read(
+                "/dl1/params",
+                [HillasParametersContainer(prefix=""), LeakageContainer(prefix="")],
+                prefixes=True,
+            )
+            hillas_, leakage_ = next(generator)
+
+        for value, read_value in zip(
+            leakage_container.as_dict().values(), leakage_.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        for value, read_value in zip(
+            hillas_parameter_container.as_dict().values(), hillas_.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+
+def test_read_duplicated_container_types():
+    hillas_config_1 = HillasParametersContainer(
+        x=1 * u.m, y=2 * u.m, length=3 * u.m, width=4 * u.m, prefix="hillas_1"
+    )
+    hillas_config_2 = HillasParametersContainer(
+        x=2 * u.m, y=3 * u.m, length=4 * u.m, width=5 * u.m, prefix="hillas_2"
+    )
+
+    with tempfile.NamedTemporaryFile() as f:
+        with HDF5TableWriter(f.name, group_name="dl1", add_prefix=True) as writer:
+            writer.write("params", [hillas_config_1, hillas_config_2])
+
+        df = pd.read_hdf(f.name, key="/dl1/params")
+        assert "hillas_1_x" in df.columns
+        assert "hillas_2_x" in df.columns
+
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read(
+                "/dl1/params",
+                [HillasParametersContainer(), HillasParametersContainer()],
+                prefixes=["hillas_1", "hillas_2"],
+            )
+            hillas_1, hillas_2 = next(generator)
+
+        for value, read_value in zip(
+            hillas_config_1.as_dict().values(), hillas_1.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+        for value, read_value in zip(
+            hillas_config_2.as_dict().values(), hillas_2.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
+
+
+def test_custom_prefix():
+    container = HillasParametersContainer(
+        x=1 * u.m, y=1 * u.m, length=1 * u.m, width=1 * u.m
+    )
+    container.prefix = "custom"
+    with tempfile.NamedTemporaryFile() as f:
+        with HDF5TableWriter(f.name, group_name="dl1", add_prefix=True) as writer:
+            writer.write("params", container)
+
+        with HDF5TableReader(f.name) as reader:
+            generator = reader.read(
+                "/dl1/params", HillasParametersContainer(), prefixes="custom"
+            )
+            read_container = next(generator)
+        assert isinstance(read_container, HillasParametersContainer)
+        for value, read_value in zip(
+            container.as_dict().values(), read_container.as_dict().values()
+        ):
+            np.testing.assert_equal(value, read_value)
 
 
 def test_units():
@@ -152,23 +303,25 @@ def test_write_large_integer():
 def test_read_container(temp_h5_file):
     r0tel1 = R0CameraContainer()
     r0tel2 = R0CameraContainer()
-    mc = MCEventContainer()
+    sim_shower = SimulatedShowerContainer()
 
     with HDF5TableReader(temp_h5_file) as reader:
 
         # get the generators for each table
-        mctab = reader.read("/R0/MC", mc)
+        # test supplying a single container as well as an
+        # iterable with one entry only
+        simtab = reader.read("/R0/sim_shower", (sim_shower,))
         r0tab1 = reader.read("/R0/tel_001", r0tel1)
         r0tab2 = reader.read("/R0/tel_002", r0tel2)
 
         # read all 3 tables in sync
         for ii in range(3):
 
-            m = next(mctab)
+            m = next(simtab)[0]
             r0_1 = next(r0tab1)
             r0_2 = next(r0tab2)
 
-            print("MC:", m)
+            print("sim_shower:", m)
             print("t0:", r0_1.waveform)
             print("t1:", r0_2.waveform)
             print("---------------------------")
@@ -179,11 +332,11 @@ def test_read_container(temp_h5_file):
 
 def test_read_whole_table(temp_h5_file):
 
-    mc = MCEventContainer()
+    sim_shower = SimulatedShowerContainer()
 
     with HDF5TableReader(temp_h5_file) as reader:
 
-        for cont in reader.read("/R0/MC", mc):
+        for cont in reader.read("/R0/sim_shower", sim_shower):
             print(cont)
 
 
@@ -224,13 +377,13 @@ def test_reader_closes_file(temp_h5_file):
 
 def test_with_context_reader(temp_h5_file):
 
-    mc = MCEventContainer()
+    sim_shower = SimulatedShowerContainer()
 
     with HDF5TableReader(temp_h5_file) as h5_table:
 
         assert h5_table._h5file.isopen == 1
 
-        for cont in h5_table.read("/R0/MC", mc):
+        for cont in h5_table.read("/R0/sim_shower", sim_shower):
             print(cont)
 
     assert h5_table._h5file.isopen == 0
@@ -346,11 +499,15 @@ class WithNormalEnum(Container):
         physics = 2
         calibration = 3
 
+    foo = Field(5, "foo field to test if this still works with more fields")
+
     event_type = Field(
         EventType.calibration,
         f"type of event, one of: {list(EventType.__members__.keys())}",
     )
 
+    bar = Field(10, "bar field to test if this still works with more fields")
+
 
 def test_read_write_container_with_enum(tmp_path):
     tmp_file = tmp_path / "container_with_enum.hdf5"
@@ -359,6 +516,8 @@ def test_read_write_container_with_enum(tmp_path):
         data = WithNormalEnum()
         for i in range(n_event):
             data.event_type = data.EventType(i % 3 + 1)
+            data.foo = i
+            data.bar = i * 2
             yield data
 
     with HDF5TableWriter(tmp_file, group_name="data") as h5_table:
