@@ -7,6 +7,7 @@ from itertools import zip_longest
 import pytest
 from astropy.time import Time
 from pathlib import Path
+from traitlets.config import Config
 
 
 from ctapipe.calib.camera.gainselection import ThresholdGainSelector
@@ -57,7 +58,7 @@ def test_simtel_event_source_on_gamma_test_one_event():
         input_url=gamma_test_large_path, allowed_tels={3, 4}
     ) as reader:
         for event in reader:
-            assert event.r0.tels_with_data.issubset(reader.allowed_tels)
+            assert set(event.r0.tel).issubset(reader.allowed_tels)
 
 
 def test_that_event_is_not_modified_after_loop():
@@ -75,7 +76,7 @@ def test_that_event_is_not_modified_after_loop():
         assert event.index.event_id == last_event.index.event_id
 
 
-def test_additional_meta_data_from_mc_header():
+def test_additional_meta_data_from_simulation_config():
     with SimTelEventSource(input_url=gamma_test_large_path) as reader:
         data = next(iter(reader))
 
@@ -83,12 +84,12 @@ def test_additional_meta_data_from_mc_header():
     from astropy import units as u
     from astropy.coordinates import Angle
 
-    assert data.mcheader.corsika_version == 6990
-    assert data.mcheader.spectral_index == -2.0
-    assert data.mcheader.shower_reuse == 20
-    assert data.mcheader.core_pos_mode == 1
-    assert data.mcheader.diffuse == 1
-    assert data.mcheader.atmosphere == 26
+    assert reader.simulation_config.corsika_version == 6990
+    assert reader.simulation_config.spectral_index == -2.0
+    assert reader.simulation_config.shower_reuse == 20
+    assert reader.simulation_config.core_pos_mode == 1
+    assert reader.simulation_config.diffuse == 1
+    assert reader.simulation_config.atmosphere == 26
 
     # value read by hand from input card
     name_expectation = {
@@ -106,7 +107,7 @@ def test_additional_meta_data_from_mc_header():
     }
 
     for name, expectation in name_expectation.items():
-        value = getattr(data.mcheader, name)
+        value = getattr(reader.simulation_config, name)
 
         assert value.unit == expectation.unit
         assert np.isclose(
@@ -118,9 +119,9 @@ def test_properties():
     source = SimTelEventSource(input_url=gamma_test_large_path)
 
     assert source.is_simulation
-    assert source.mc_header.corsika_version == 6990
-    assert source.datalevels == (DataLevel.R0, DataLevel.R1, DataLevel.DL0)
-    assert source.obs_id == 7514
+    assert source.simulation_config.corsika_version == 6990
+    assert source.datalevels == (DataLevel.R0, DataLevel.R1)
+    assert source.obs_ids == [7514]
 
 
 def test_gamma_file():
@@ -132,9 +133,9 @@ def test_gamma_file():
 
         for event in reader:
             if event.count == 0:
-                assert event.r0.tels_with_data == {38, 47}
+                assert event.r0.tel.keys() == {38, 47}
             elif event.count == 1:
-                assert event.r0.tels_with_data == {11, 21, 24, 26, 61, 63, 118, 119}
+                assert event.r0.tel.keys() == {11, 21, 24, 26, 61, 63, 118, 119}
             else:
                 break
 
@@ -172,9 +173,9 @@ def test_allowed_telescopes():
     ) as reader:
 
         for event in reader:
-            assert event.r0.tels_with_data.issubset(allowed_tels)
-            assert event.r1.tels_with_data.issubset(allowed_tels)
-            assert event.dl0.tels_with_data.issubset(allowed_tels)
+            assert set(event.r0.tel).issubset(allowed_tels)
+            assert set(event.r1.tel).issubset(allowed_tels)
+            assert set(event.dl0.tel).issubset(allowed_tels)
 
     # test that updating the allowed_tels mask works
     new_allowed_tels = {1, 2}
@@ -185,9 +186,9 @@ def test_allowed_telescopes():
         # change allowed_tels after __init__
         reader.allowed_tels = new_allowed_tels
         for event in reader:
-            assert event.r0.tels_with_data.issubset(new_allowed_tels)
-            assert event.r1.tels_with_data.issubset(new_allowed_tels)
-            assert event.dl0.tels_with_data.issubset(new_allowed_tels)
+            assert set(event.r0.tel).issubset(new_allowed_tels)
+            assert set(event.r1.tel).issubset(new_allowed_tels)
+            assert set(event.dl0.tel).issubset(new_allowed_tels)
 
 
 def test_calibration_events():
@@ -207,7 +208,7 @@ def test_calibration_events():
         EventType.SUBARRAY,
     ]
     with SimTelEventSource(
-        input_url=calib_events_path, skip_calibration_events=False,
+        input_url=calib_events_path, skip_calibration_events=False
     ) as reader:
 
         for event, expected_type in zip_longest(reader, expected_types):
@@ -230,8 +231,8 @@ def test_trigger_times():
 def test_true_image():
     with SimTelEventSource(input_url=calib_events_path) as reader:
 
-        for e in reader:
-            for tel in e.mc.tel.values():
+        for event in reader:
+            for tel in event.simulation.tel.values():
                 assert np.count_nonzero(tel.true_image) > 0
 
 
@@ -255,7 +256,7 @@ def test_apply_simtel_r1_calibration_1_channel():
     n_samples = 128
 
     r0_waveforms = np.zeros((n_channels, n_pixels, n_samples))
-    pedestal = np.full((n_channels, n_pixels), 20 * n_samples)
+    pedestal = np.full((n_channels, n_pixels), 20)
     dc_to_pe = np.full((n_channels, n_pixels), 0.5)
 
     gain_selector = ThresholdGainSelector(threshold=90)
@@ -267,7 +268,7 @@ def test_apply_simtel_r1_calibration_1_channel():
     assert r1_waveforms.ndim == 2
     assert r1_waveforms.shape == (n_pixels, n_samples)
 
-    ped = pedestal / n_samples
+    ped = pedestal
     assert r1_waveforms[0, 0] == (r0_waveforms[0, 0, 0] - ped[0, 0]) * dc_to_pe[0, 0]
     assert r1_waveforms[1, 0] == (r0_waveforms[0, 1, 0] - ped[0, 1]) * dc_to_pe[0, 1]
 
@@ -282,8 +283,8 @@ def test_apply_simtel_r1_calibration_2_channel():
     r0_waveforms[1, :, :] = 1
 
     pedestal = np.zeros((n_channels, n_pixels))
-    pedestal[0] = 90 * n_samples
-    pedestal[1] = 0.9 * n_samples
+    pedestal[0] = 90
+    pedestal[1] = 0.9
 
     dc_to_pe = np.zeros((n_channels, n_pixels))
     dc_to_pe[0] = 0.01
@@ -299,7 +300,7 @@ def test_apply_simtel_r1_calibration_2_channel():
     assert r1_waveforms.ndim == 2
     assert r1_waveforms.shape == (n_pixels, n_samples)
 
-    ped = pedestal / n_samples
+    ped = pedestal
     assert r1_waveforms[0, 0] == (r0_waveforms[1, 0, 0] - ped[1, 0]) * dc_to_pe[1, 0]
     assert r1_waveforms[1, 0] == (r0_waveforms[0, 1, 0] - ped[0, 1]) * dc_to_pe[0, 1]
 
@@ -329,3 +330,11 @@ def test_effective_focal_length():
     assert focal_length_nominal > 0
     assert focal_length_effective > 0
     assert focal_length_nominal != focal_length_effective
+
+
+def test_only_config():
+    config = Config()
+    config.SimTelEventSource.input_url = gamma_test_large_path
+
+    s = SimTelEventSource(config=config)
+    assert s.input_url == Path(gamma_test_large_path).absolute()
