@@ -7,11 +7,7 @@ import logging
 import numpy as np
 import astropy.units as u
 
-from ..containers import (
-    DataContainer,
-    DL1CameraContainer,
-    EventIndexContainer,
-)
+from ..containers import ArrayEventContainer, DL1CameraContainer, EventIndexContainer
 from ..core import traits
 from ..core import TelescopeComponent
 from ..image import toymodel
@@ -24,26 +20,26 @@ logger = logging.getLogger(__name__)
 class ToyEventSource(EventSource, TelescopeComponent):
 
     trigger_probability = traits.FloatTelescopeParameter(
-        default_value=0.5, help="Probability that the telescope has an event",
+        default_value=0.5, help="Probability that the telescope has an event"
     ).tag(config=True)
 
     min_length_m = traits.FloatTelescopeParameter(
-        default_value=0.05, help="Minimum length m",
+        default_value=0.05, help="Minimum length m"
     ).tag(config=True)
     max_length_m = traits.FloatTelescopeParameter(
-        default_value=0.3, help="Maximum length in m",
+        default_value=0.3, help="Maximum length in m"
     ).tag(config=True)
     min_eccentricity = traits.FloatTelescopeParameter(
-        default_value=0.8, help="Minimum eccentricity = sqrt(1 - width**2/length**2)",
+        default_value=0.8, help="Minimum eccentricity = sqrt(1 - width**2/length**2)"
     ).tag(config=True)
     max_eccentricity = traits.FloatTelescopeParameter(
-        default_value=0.98, help="Maximum eccentricity = sqrt(1 - width**2/length**2)",
+        default_value=0.98, help="Maximum eccentricity = sqrt(1 - width**2/length**2)"
     ).tag(config=True)
     min_skewness = traits.FloatTelescopeParameter(
-        default_value=0.1, help="Minimum skewness",
+        default_value=0.1, help="Minimum skewness"
     ).tag(config=True)
     max_skewness = traits.FloatTelescopeParameter(
-        default_value=0.5, help="Maximum skewness",
+        default_value=0.5, help="Maximum skewness"
     ).tag(config=True)
 
     def __init__(self, subarray, config=None, parent=None, **kwargs):
@@ -60,8 +56,8 @@ class ToyEventSource(EventSource, TelescopeComponent):
         return self._subarray
 
     @property
-    def obs_id(self):
-        return -1
+    def obs_ids(self):
+        return [-1]
 
     @property
     def is_simulation(self):
@@ -90,14 +86,13 @@ class ToyEventSource(EventSource, TelescopeComponent):
 
     def generate_event(self):
 
-        event = DataContainer(
+        event = ArrayEventContainer(
             index=EventIndexContainer(obs_id=1, event_id=self.event_id),
             trigger=None,
             r0=None,
             dl0=None,
             dl2=None,
-            mc=None,
-            mcheader=None,
+            simulation=None,
             count=self.event_id,
             calibration=None,
         )
@@ -117,10 +112,10 @@ class ToyEventSource(EventSource, TelescopeComponent):
 
             # draw length
             length = np.random.uniform(
-                self.min_length_m.tel[tel_id], self.max_length_m.tel[tel_id],
+                self.min_length_m.tel[tel_id], self.max_length_m.tel[tel_id]
             )
             eccentricity = np.random.uniform(
-                self.min_eccentricity.tel[tel_id], self.max_eccentricity.tel[tel_id],
+                self.min_eccentricity.tel[tel_id], self.max_eccentricity.tel[tel_id]
             )
             width = self.calc_width(eccentricity, length)
 
@@ -138,7 +133,7 @@ class ToyEventSource(EventSource, TelescopeComponent):
                 psi=f"{psi}d",
                 skewness=skewness,
             )
-            image, _, _ = model.generate_image(cam, intensity,)
+            image, _, _ = model.generate_image(cam, intensity)
 
             event.dl1.tel[tel_id] = DL1CameraContainer(image=image)
 
