@@ -1,7 +1,6 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from .HillasReconstructor import HillasReconstructor, Reconstructor
 from .ImPACT import ImPACTReconstructor
-from .energy_regressor import EnergyRegressor
 from .shower_max import ShowerMaxEstimator
 
 
@@ -9,6 +8,5 @@ __all__ = [
     "HillasReconstructor",
     "Reconstructor",
     "ImPACTReconstructor",
-    "EnergyRegressor",
     "ShowerMaxEstimator",
 ]
