@@ -11,6 +11,7 @@ from ctapipe.core import Component, Tool
 from ctapipe.core import traits
 from ctapipe.image.extractor import ImageExtractor
 from ctapipe.io import EventSource
+from ctapipe.io.datalevels import DataLevel
 from ctapipe.utils import get_dataset_path
 from ctapipe.visualization import CameraDisplay
 
@@ -165,7 +166,14 @@ class DisplayDL1Calib(Tool):
         self.plotter = None
 
     def setup(self):
-        self.eventsource = EventSource(parent=self)
+        self.eventsource = EventSource.from_config(parent=self)
+        compatible_datalevels = [DataLevel.R1, DataLevel.DL0, DataLevel.DL1_IMAGES]
+
+        if not self.eventsource.has_any_datalevel(compatible_datalevels):
+            raise Exception(
+                "The input file contains no pixelwise information. "
+                "Images can not be constructed."
+            )
         subarray = self.eventsource.subarray
 
         self.calibrator = CameraCalibrator(parent=self, subarray=subarray)
@@ -175,8 +183,9 @@ class DisplayDL1Calib(Tool):
         for event in self.eventsource:
             self.calibrator(event)
 
-            tel_list = event.r0.tel.keys()
+            tel_list = event.dl1.tel.keys()
 
+            tel_list = event.dl1.tel.keys()
             if self.telescope:
                 if self.telescope not in tel_list:
                     continue
