@@ -5,7 +5,7 @@ purposes
 import sys
 
 from ctapipe.calib import CameraCalibrator
-from ctapipe.io import event_source
+from ctapipe.io import EventSource
 from ctapipe.utils import get_dataset_path
 
 if __name__ == "__main__":
@@ -15,7 +15,7 @@ if __name__ == "__main__":
     else:
         filename = get_dataset_path("gamma_test_large.simtel.gz")
 
-    with event_source(filename, max_events=1) as source:
+    with EventSource(filename, max_events=1) as source:
         calib = CameraCalibrator(subarray=source.subarray)
         for event in source:
             calib(event)
